@@ -11,7 +11,7 @@ from typing import Dict
 from utils_find_1st import find_1st, cmp_equal
 
 from agora.io.bridge import BridgeH5
-from aliby.utils import timed
+from agora.io.utils import timed
 
 
 #################### Dynamic version ##################################
